import { ItemBucketMetadata, Client } from 'minio';
export type UploadedObjectInfo = {
  etag: string;
  lastModified?: Date;
  size?: number;
  versionId: string;
  metadata?: ItemBucketMetadata;
};
export type StatObjectResult = {
  size: number;
  etag: string;
  lastModified: Date;
  metaData: ItemBucketMetadata;
  versionId?: string | null;
};
export type ListFileObject = {
  name: string;
  size: number;
  lastModified: Date;
  etag: string;
};
export type ListDirectoryObject = {
  prefix: string;
  size: number;
};
export type ListObjectResult = ListFileObject | ListDirectoryObject;
export interface OssBaseOperation {
  prefix: string;
  setPrefix(prefix: string): void;
  /**
   * 获取对象
   * @param objectName 对象名
   */
  getObject(objectName: string): Promise<any>;
  /**
   * 上传对象
   * @param objectName 对象名
   * @param data 数据
   */
  putObject(objectName: string, data: Buffer | string, metaData?: ItemBucketMetadata): Promise<UploadedObjectInfo>;
  /**
   * 上传文件
   * @param objectName 对象名
   * @param filePath 文件路径
   */
  fPutObject(objectName: string, filePath: string, metaData?: ItemBucketMetadata): Promise<UploadedObjectInfo>;
  /**
   * 获取对象信息
   * @param objectName 对象名
   */
  statObject(objectName: string): Promise<StatObjectResult>;
  /**
   * 删除对象
   * @param objectName 对象名
   */
  deleteObject(objectName: string): Promise<any>;
  /**
   * 列出对象
   * @param objectName 对象名
   * @param opts 选项
   * @param opts.recursive 是否递归
   * @param opts.startAfter 开始位置
   */
  listObjects(
    objectName: string,
    opts?: {
      /**
       * 是否递归
       */
      recursive?: boolean;
      /**
       * 开始位置
       */
      startAfter?: string;
    },
  ): Promise<ListObjectResult[]>;
  /**
   * 复制对象
   * @param sourceObject 源对象
   * @param targetObject 目标对象
   */
  copyObject: Client['copyObject'];
}

export interface OssService extends OssBaseOperation {
  owner: string;
}
