import { OssBase, OssBaseOptions } from '../index.ts';
import { OssService } from '../core/type.ts';
import * as util from '../util/index.ts';

export class ConfigOssService extends OssBase implements OssService {
  owner: string;
  constructor(opts: OssBaseOptions<{ owner: string }>) {
    super(opts);
    this.owner = opts.owner;
    this.setPrefix(`${this.owner}/config/1.0.0/`);
  }
  async listAllFile() {
    const list = await this.listObjects<true>('');
    return list.filter((item) => item.size > 0 && this.isEndWithJson(item.name));
  }
  async listAll() {
    return await this.listObjects<false>('');
  }
  configMap = new Map<string, any>();
  keys: string[] = [];
  async getAllConfigJson() {
    const list = await this.listAllFile();
    return list;
  }
  isEndWithJson(string: string) {
    return string?.endsWith?.(`.json`);
  }
  putJsonObject(key: string, data: any) {
    const json = util.hashSringify(data);
    return this.putObject(key, json, {
      'Content-Type': 'application/json',
      'app-source': 'user-config-app',
      'Cache-Control': 'max-age=31536000, immutable',
    });
  }
  async getObjectList(objectNameList: string[]) {
    const jsonMap = new Map<string, Record<string, any>>();
    for (const objectName of objectNameList) {
      try {
        const json = await this.getJson(objectName);
        jsonMap.set(objectName, json);
      } catch (error) {
        console.error(error);
        continue;
      }
    }
    return jsonMap;
  }
  async getList() {
    const list = await this.listAllFile();
    /**
     * key -> etag
     */
    const keyEtagMap = new Map<string, Etag>();
    const listKeys = list.map((item) => {
      const key = item.name.replace(this.prefix, '');
      keyEtagMap.set(key, item.etag);
      return {
        ...item,
        key,
      };
    });
    type Etag = string;
    const keys = Array.from(keyEtagMap.keys());
    return { list: listKeys, keys, keyEtagMap };
  }
}
